This crate contains Value, an enum representing all values that can be used as
node’s input and output, and utilities for working with Value.
Common operations:
- Converting
Valueto Rust types. - Converting Rust types to
Value. - Receiving
flow_value::Mapas node’s input. - Returning
flow_value::Mapas node’s output. - Converting
Valueto/from JSON to use in HTTP APIs and database. - Getting and updating nested values with JSON Pointer syntax.
Modules
Macros
Structs
- Bytes
- Const
Bytes - Decimal
Decimalrepresents a 128 bit representation of a fixed-precision decimal number. The finite set of values of typeDecimalare of the form m / 10e, where m is an integer such that -296 < m < 296, and e is an integer between 0 and 28 inclusive.- Five8
Buffer32 - Five8
Buffer64
Enums
Functions
- five8_
decode_ 32 - five8_
decode_ 64 - from_
map - Interpret a
Mapas an instance of typeT - from_
value - Interpret a
Valueas an instance of typeT - to_map
- Convert a
TintoMap. - to_
value - Convert a
TintoValue.